#
# spec file for package python-ipyparallel
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define gitversion 6.3.0.dev0

%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define         skip_python2 1
Name:           python-ipyparallel
Version:        6.3.0~git.20191010T150914.ce996ae
Release:        lp152.2.1
%define doc_ver 6.2.3
Summary:        Interactive parallel computing library for IPython
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/ipython/ipyparallel
Source:         ipyparallel-%{version}.tar.xz
Source1:        https://media.readthedocs.org/pdf/ipyparallel/%{doc_ver}/ipyparallel.pdf
Source2:        https://media.readthedocs.org/htmlzip/ipyparallel/%{doc_ver}/ipyparallel.zip
BuildRequires:  %{python_module notebook}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  unzip
# SECTION test requirements
BuildRequires:  %{python_module decorator}
BuildRequires:  %{python_module ipykernel >= 4.4}
BuildRequires:  %{python_module ipython >= 4}
BuildRequires:  %{python_module ipython-iptest >= 4}
BuildRequires:  %{python_module ipython_genutils}
BuildRequires:  %{python_module jupyter-client}
BuildRequires:  %{python_module jupyter-core}
BuildRequires:  %{python_module mock}
BuildRequires:  %{python_module pytest-cov}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module python-dateutil >= 2.1}
BuildRequires:  %{python_module pyzmq >= 13}
BuildRequires:  %{python_module testpath}
BuildRequires:  %{python_module tornado >= 4}
BuildRequires:  %{python_module traitlets >= 4.3}
# /SECTION
Requires:       python-decorator
Requires:       python-ipykernel >= 4.4
Requires:       python-ipython >= 4
Requires:       python-ipython_genutils
Requires:       python-jupyter-client
Requires:       python-python-dateutil >= 2.1
Requires:       python-pyzmq >= 13
Requires:       python-tornado >= 4
Requires:       python-traitlets >= 4.3
Requires(post): update-alternatives
Requires(postun): update-alternatives
Recommends:     jupyter-ipyparallel = %{version}
Recommends:     python-mpi4py
Recommends:     python-pymongo
Provides:       python-jupyter_ipyparallel = %{version}
Obsoletes:      python-jupyter_ipyparallel < %{version}
BuildArch:      noarch
%python_subpackages

%description
Use multiple instances of IPython in parallel, interactively.

This package provides the python interface.

%package     -n jupyter-ipyparallel
Summary:        Interactive parallel computing library for IPython
Group:          Development/Languages/Python
Requires:       jupyter-jupyter-core
Requires:       jupyter-notebook
Requires:       python3-ipyparallel = %{version}
Provides:       python-jupyter_ipyparallel-nbextension = %{version}
Obsoletes:      python-jupyter_ipyparallel-nbextension < %{version}

%description -n jupyter-ipyparallel
Use multiple instances of IPython in parallel, interactively.

This package provides the jupyter notebook extension.

%package     -n jupyter-ipyparallel-doc
Summary:        Documentation for ipyparallel
Group:          Documentation/Other
Provides:       %{python_module ipyparallel-doc = %{version}}
Provides:       %{python_module jupyter_ipyparallel-doc = %{version}}
Obsoletes:      %{python_module jupyter_ipyparallel-doc < %{version}}

%description -n jupyter-ipyparallel-doc
Documentation and help files for ipyparallel.

%prep
%setup -q -n ipyparallel-%{version}
unzip %{SOURCE2}
mv ipyparallel-%{doc_ver} docs/html
rm -f docs/html/.buildinfo

%build
%python_build

%install
%python_install

%python_expand %fdupes %{buildroot}%{$python_sitelib}

%{jupyter_move_config}

# Prepare for update-alternatives
%python_clone -a %{buildroot}%{_bindir}/ipcluster
%python_clone -a %{buildroot}%{_bindir}/ipcontroller
%python_clone -a %{buildroot}%{_bindir}/ipengine

echo pass4
# These files are meant to be runnable stand-alone, so they should be executable
%{python_expand pushd %{buildroot}%{$python_sitelib}
chmod a+x ipyparallel/apps/*app.py
chmod a-x ipyparallel/apps/baseapp.py
chmod a+x ipyparallel/controller/heartmonitor.py
# Fix wrong-script-interpreter
sed -i "s|#!%{_bindir}/env python|#!%__$python|" ipyparallel/apps/*app.py
sed -i "s|#!%{_bindir}/env python|#!%__$python|" ipyparallel/controller/heartmonitor.py
# Deduplicating files can generate a RPMLINT warning for pyc mtime
$python -m compileall -d %{$python_sitearch} ipyparallel/apps/
$python -O -m compileall -d %{$python_sitearch} ipyparallel/apps/
$python -m compileall -d %{$python_sitearch} ipyparallel/controller/heartmonitor.py
$python -O -m compileall -d %{$python_sitearch} ipyparallel/controller/heartmonitor.py
%fdupes .
popd
}

mkdir -p %{buildroot}%{_docdir}/jupyter-ipyparallel

cp %{SOURCE1} %{buildroot}%{_docdir}/jupyter-ipyparallel/
cp -r docs/html %{buildroot}%{_docdir}/jupyter-ipyparallel/

%fdupes %{buildroot}%{_jupyter_prefix}

%check
%pytest -k 'not test_disambiguate_ip and not test_bind_kernel and not test_autopx_blocking and not test_warning_on_hostname_match'

%post
%{python_install_alternative ipcluster ipcontroller ipengine}

%postun
%python_uninstall_alternative ipcluster

%files %{python_files}
%license COPYING.md
%python_alternative %{_bindir}/ipcluster
%python_alternative %{_bindir}/ipcontroller
%python_alternative %{_bindir}/ipengine
%{python_sitelib}/ipyparallel-%{gitversion}-py*.egg-info
%{python_sitelib}/ipyparallel/

%files -n jupyter-ipyparallel
%license COPYING.md
%doc README.md
%{_jupyter_nbextension_dir}/ipyparallel/
%config %{_jupyter_servextension_confdir}/ipyparallel-serverextension.json
%config %{_jupyter_nb_tree_confdir}/ipyparallel-nbextension.json

%files -n jupyter-ipyparallel-doc
%license COPYING.md
%dir %{_docdir}/jupyter-ipyparallel/
%{_docdir}/jupyter-ipyparallel/ipyparallel.pdf
%{_docdir}/jupyter-ipyparallel/html/

%changelog
* Thu Apr 23 2020 Tomáš Chvátal <tchvatal@suse.com>
- Drop py2 code from py3 only package
* Thu Mar 12 2020 hpj@urpla.net
- Switch to git scm service
- Update to version 6.3.0~git.20191010T150914.ce996ae:
  * fix maybe_future
  * only yield Futures
  * pytest captures output
  * importing joblib can raise TypeError on py38
  * unpin tornado
  * update dask api
  * update mocking for latest ipykernel
  * Use unittest.mock if available
* Tue Nov 12 2019 Todd R <toddrme2178@gmail.com>
- Drop python2 support due to python-notebook dropping python2 support
* Mon Aug 26 2019 Todd R <toddrme2178@gmail.com>
- Fix spurious test failure
* Sun Aug 11 2019 Todd R <toddrme2178@gmail.com>
- Switch from wheel to sdist.
* Wed Jun 12 2019 Todd R <toddrme2178@gmail.com>
- Update to 6.2.4
  * Improve compatibility with ipykernel 5
  * Fix %%autopx with IPython 7
  * Fix non-local ip warning when using current hostname
* Thu Apr 25 2019 Todd R <toddrme2178@gmail.com>
- Rename to to match python package naming guidelines.
- Split jupyter components into own subpackage.
* Sat Dec 22 2018 Todd R <toddrme2178@gmail.com>
- Update to 6.2.3
  * Fix compatibility for execute requests with ipykernel 5
  * require ipykernel >= 4.4
* Thu Aug  2 2018 toddrme2178@gmail.com
- Update to 6.2.2
  * Fix compatibility with tornado 4, broken in 6.2.0
  * Fix encoding of engine and controller logs in ipcluster --debug on Python 3
  * Fix compatiblity with joblib 0.12
  * Include LICENSE file in wheels
* Thu Jun  7 2018 toddrme2178@gmail.com
- Update to version 6.2.1
  * Workaround a setuptools issue preventing installation from sdist on Windows
- Update to version 6.2.0
  * Drop support for Python 3.3. IPython parallel now requires Python 2.7 or >= 3.4.
  * Further fixes for compatibility with tornado 5 when run with asyncio (Python 3)
  * Fix for enabling clusters tab via nbextension
  * Multiple fixes for handling when engines stop unexpectedly
  * Installing IPython Parallel enables the Clusters tab extension by default, without any additional commands.
- Switch to wheel-based install
- Run tests in main package
- Remove -doc subpackage and use upstream-build docs
* Thu Feb 15 2018 toddrme2178@gmail.com
- Update to 6.1.1
  * Fix regression in 6.1.0 preventing BatchSpawners (PBS, etc.) from launching with ipcluster.
- Update to 6.1.0
  + Compatibility fixes with related packages:
  * Fix compatibility with pyzmq 17 and tornado 5.
  * Fix compatibility with IPython ≥ 6.
  * Improve compatibility with dask.distributed ≥ 1.18.
  + New features:
  * Add :attr:`namespace` to BatchSpawners for easier extensibility.
  * Support serializing partial functions.
  * Support hostnames for machine location, not just ip addresses.
  * Add ``--location`` argument to ipcluster for setting the controller location.
    It can be a hostname or ip.
  * Engine rank matches MPI rank if engines are started with ``--mpi``.
  * Avoid duplicate pickling of the same object in maps, etc.
* Tue Feb 13 2018 toddrme2178@gmail.com
- Update url
* Wed Sep 20 2017 toddrme2178@gmail.com
- Further improvements to notebook extension handling
* Wed Sep 20 2017 toddrme2178@gmail.com
- Fix notebook extension handling
* Sun Aug  6 2017 toddrme2178@gmail.com
- Fix script interpeter.
* Thu Apr 27 2017 toddrme2178@gmail.com
- Implement single-spec version.
* Fri Apr  7 2017 toddrme2178@gmail.com
- Clean up update-alternatives usage.
* Thu Mar 30 2017 toddrme2178@gmail.com
- Update to 6.0.2
  * Upload fixed sdist for 6.0.1.
- Update to 6.0.1
  * Small encoding fix for Python 2.
- Update to 6.0
  * Due to a compatibility change and semver, this is a major release. However, it is not a big release.
  * The main compatibility change is that all timestamps are now timezone-aware UTC timestamps.
  * This means you may see comparison errors if you have code that uses datetime objects without timezone info (so-called naïve datetime objects).
  * Rename :meth:`Client.become_distributed` to :meth:`Client.become_dask`.
    :meth:`become_distributed` remains as an alias.
  * import joblib from a public API instead of a private one
    when using IPython Parallel as a joblib backend.
  * Compatibility fix in extensions for security changes in notebook 4.3
- Update to 5.2
  * Fix compatibility with changes in ipykernel 4.3, 4.4
  * Improve inspection of ``@remote`` decorated functions
  * :meth:`Client.wait` accepts any Future.
  * Add ``--user`` flag to :command:`ipcluster nbextension`
  * Default to one core per worker in :meth:`Client.become_distributed`.
    Override by specifying `ncores` keyword-argument.
  * Subprocess logs are no longer sent to files by default in :command:`ipcluster`.
- Update to 5.1
  * IPython Parallel 5.1 adds integration with other parallel computing tools,
    such as `dask.distributed <https://distributed.readthedocs.io>`_ and `joblib <https://pythonhosted.org/joblib>`__.
  * IPython parallel now supports the notebook-4.2 API for enabling server extensions,
    to provide the IPython clusters tab
    jupyter serverextension enable --py ipyparallel
    jupyter nbextension install --py ipyparallel
    jupyter nbextension enable --py ipyparallel
    though you can still use the more convenient single-call::
    ipcluster nbextension enable
    which does all three steps above.
  * `Slurm <https://computing.llnl.gov/tutorials/linux_clusters>`_ support is added to ipcluster.
- Update to 5.0.1
  * Fix imports in :meth:`use_cloudpickle`, :meth:`use_dill`.
  * Various typos and documentation updates to catch up with 5.0.
* Wed Feb 17 2016 toddrme2178@gmail.com
- specfile:
  * update copyright year
- update to version 5.0.0:
  * The highlight of ipyparallel 5.0 is that the Client has been
    reorganized a bit to use Futures. AsyncResults are now a Future
    subclass, so they can be `yield`ed in coroutines, etc. Views have
    also received an Executor interface. This rewrite better connects
    results to their handles, so the Client.results cache should no
    longer grow unbounded.
    + The Executor API :class:`ipyparallel.ViewExecutor`
    + Creating an Executor from a Client:
    :meth:`ipyparallel.Client.executor`
    + Each View has an :attr:`executor` attribute
  * Part of the Future refactor is that Client IO is now handled in a
    background thread, which means that :meth:`Client.spin_thread` is
    obsolete and deprecated.
  * Other changes:
    + Add :command:`ipcluster nbextension enable|disable` to toggle
    the clusters tab in Jupyter notebook
  * Less interesting development changes for users: Some
    IPython-parallel extensions to the IPython kernel have been moved
    to the ipyparallel package:
    + :mod:`ipykernel.datapub` is now :mod:`ipyparallel.datapub`
    + ipykernel Python serialization is now in
    :mod:`ipyparallel.serialize`
    + apply_request message handling is implememented in a Kernel
    subclass, rather than the base ipykernel Kernel.
- update to version 4.1.0:
  * Add :meth:`.Client.wait_interactive`
  * Improvements for specifying engines with SSH launcher.
- Split documentation into own subpackage to speed up builds.
* Mon Oct  5 2015 toddrme2178@gmail.com
- Build documentation
* Fri Aug 28 2015 toddrme2178@gmail.com
- Fix conflict.
* Wed Aug 26 2015 toddrme2178@gmail.com
- Initial version
